/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the New BSD License (3-clause license).
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the New BSD License (3-clause license)
 * for more details.
 *
 * You should have received a copy of the New BSD License (3-clause license)
 * along with this program/library; If not, see http://directory.fsf.org/wiki/License:BSD_3Clause/
 * for the New BSD License (3-clause license).
 */
package com.ebmwebsourcing.easycommons.lang;

import java.util.ArrayList;
import java.util.List;

import org.junit.Test;

import static org.junit.Assert.assertEquals;

import com.ebmwebsourcing.easycommons.lang.CollectionHelper.Filter;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 * 
 */
public class CollectionHelperTest {

    class PairNumberFilter implements Filter<Integer> {

        @Override
        public boolean accept(Integer item) {
            return item % 2 == 0;
        }

    }

    class NumberFourFilter implements Filter<Integer> {

        @Override
        public boolean accept(Integer item) {
            return item == 4;
        }

    }

    @Test
    public void filterListWithOneFilter() {
        List<Integer> lst = new ArrayList<Integer>();
        for (int i = 1; i <= 10; i++) {
            lst.add(i);
        }
        assertEquals(10, lst.size());
        List<Filter<Integer>> filters = new ArrayList<CollectionHelper.Filter<Integer>>();
        filters.add(new PairNumberFilter());
        CollectionHelper.filter(lst, filters);
        assertEquals(5, lst.size());
        int i = 2;
        for (Integer integer : lst) {
            assertEquals(i, integer.intValue());
            i += 2;
        }
    }

    @Test
    public void filterListWithTwoFilter() {
        List<Integer> lst = new ArrayList<Integer>();
        for (int i = 1; i <= 10; i++) {
            lst.add(i);
        }
        assertEquals(10, lst.size());
        List<Filter<Integer>> filters = new ArrayList<CollectionHelper.Filter<Integer>>();
        filters.add(new PairNumberFilter());
        filters.add(new NumberFourFilter());
        CollectionHelper.filter(lst, filters);
        assertEquals(1, lst.size());
        assertEquals(4, lst.get(0).intValue());
    }
}
